Chiplotle Tools
================

HPGL Tools
-------------

.. autofunction:: chiplotle.tools.hpgltools.convert_coordinates_to_hpgl_absolute_path
.. autofunction:: chiplotle.tools.hpgltools.convert_relatives_to_absolutes
.. autofunction:: chiplotle.tools.hpgltools.get_all_coordinates
.. autofunction:: chiplotle.tools.hpgltools.get_bounding_box
.. autofunction:: chiplotle.tools.hpgltools.get_centroid
.. autofunction:: chiplotle.tools.hpgltools.inflate_hpgl_string
.. autofunction:: chiplotle.tools.hpgltools.inflate_hpgl_string_command
.. autofunction:: chiplotle.tools.hpgltools.is_primitive_absolute
.. autofunction:: chiplotle.tools.hpgltools.parse_hpgl_string
.. autofunction:: chiplotle.tools.hpgltools.pens_updown_to_papr
.. autofunction:: chiplotle.tools.hpgltools.pr_to_pa
.. autofunction:: chiplotle.tools.hpgltools.relativize
.. autofunction:: chiplotle.tools.hpgltools.rotate_hpglprimitives
.. autofunction:: chiplotle.tools.hpgltools.scale
.. autofunction:: chiplotle.tools.hpgltools.transpose

Input-output tools
---------------------

.. autofunction:: chiplotle.tools.io.export
.. autofunction:: chiplotle.tools.io.import_hpgl_file
.. autofunction:: chiplotle.tools.io.save_hpgl
.. autofunction:: chiplotle.tools.io.view

Math tools
--------------

.. autofunction:: chiplotle.tools.mathtools.bezier_interpolation
.. autofunction:: chiplotle.tools.mathtools.catmull_interpolation
.. autofunction:: chiplotle.tools.mathtools.cumsum
.. autofunction:: chiplotle.tools.mathtools.difference
.. autofunction:: chiplotle.tools.mathtools.factors
.. autofunction:: chiplotle.tools.mathtools.interpolate_cosine
.. autofunction:: chiplotle.tools.mathtools.interpolate_exponential
.. autofunction:: chiplotle.tools.mathtools.interpolate_linear
.. autofunction:: chiplotle.tools.mathtools.lcm
.. autofunction:: chiplotle.tools.mathtools.pascal_row
.. autofunction:: chiplotle.tools.mathtools.polar_to_xy
.. autofunction:: chiplotle.tools.mathtools.rotate_2d
.. autofunction:: chiplotle.tools.mathtools.rotate_3d
.. autofunction:: chiplotle.tools.mathtools.rotate_coordinate_2d
.. autofunction:: chiplotle.tools.mathtools.rotate_coordinatearray_2d
.. autofunction:: chiplotle.tools.mathtools.superformula
.. autofunction:: chiplotle.tools.mathtools.xy_to_polar

